# Instructions for Use (Template)

## Intended Purpose
- Describe the specific tasks and user groups.

## Capabilities & Limitations
- Strengths
- Known failure modes and when not to use the system

## Installation & Configuration
- Prerequisites, environment, network/egress allowlist

## Operation
- Input requirements, expected outputs, typical latency
- Confidence & uncertainty presentation

## Human Oversight
- Oversight mode, required interventions, escalation

## Performance Characteristics
- Accuracy/quality, robustness tests summary, known trade-offs

## Logging & Monitoring
- What is logged, retention, access

## Security
- Authentication/authorization, encryption, secret handling

## Contact & Support
- Owner, support channel, incident reporting
